@@ -11,7 +11,7 @@ def query(isbn, service='wcat'):
     """
     if service == 'wcat':
         canonical = wcat.query(isbn)
-    elif service == 'googlebooks':
+    elif service == 'goob' or service == 'googlebooks':
         canonical = googlebooks.query(isbn)
     else:
         print(('Error:%s is not a recognized service!' % service))
